@@ -1,6 +1,7 @@
 import dataclasses
 import datetime
 import logging
+import os
 import pathlib
 import textwrap
 
@@ -65,7 +66,10 @@ def view_hours_worked_per_day(timesheet: model.Timesheet):
             minutia = task.minutia
             minutia = " ".join(minutia.strip().split())
             minutia = textwrap.fill(
-                minutia, initial_indent="   ", subsequent_indent="   "
+                minutia,
+                initial_indent=" " * 3,
+                subsequent_indent=" " * 3,
+                break_long_words=False,
             )
 
             modified_task = {
@@ -91,6 +95,37 @@ def view_hours_worked_per_day(timesheet: model.Timesheet):
     return out
 
 
+def view_hours_worked_per_day_summary(timesheet: model.Timesheet):
+    daily_entries = []
+
+    total_seconds = 0
+    wage_per_hour = float(os.environ.get("WAGE", 0))
+    for day in timesheet.days:
+        seconds = 0
+        for task in day.tasks.__root__:
+            seconds += durations.Duration(task.task_time).to_seconds()
+
+        total_seconds += seconds
+        delta = datetime.timedelta(seconds=seconds)
+        x1 = {
+            "date": day.date,
+            "worked_duration": timedelta_to_short_string(delta),
+            "invoice_number": day.invoice,
+            "earned": wage_per_hour * delta.seconds / 3600,
+        }
+        daily_entries.append(x1)
+
+    template = env.get_template("view_hours_worked_per_day_summary.j2")
+    daily_entries = sorted(daily_entries, key=lambda i: i["date"], reverse=True)
+    out = template.render(
+        data={
+            "summary": {"total_seconds_worked": total_seconds},
+            "entries": daily_entries,
+        }
+    )
+    return out
+
+
 def timedelta_to_short_string(td: datetime.timedelta) -> str:
     seconds = td.total_seconds()
     hours, remainder = divmod(seconds, 3600)
@@ -144,36 +179,6 @@ def view_csv(timesheet: model.Timesheet):
     return out
 
 
-def view_hours_worked_per_day_summary(timesheet: model.Timesheet):
-    daily_entries = []
-
-    total_seconds = 0
-    for day in timesheet.days:
-        seconds = 0
-        for task in day.tasks.__root__:
-            seconds += durations.Duration(task.task_time).to_seconds()
-
-        total_seconds += seconds
-        delta = datetime.timedelta(seconds=seconds)
-
-        x1 = {
-            "date": day.date,
-            "worked_duration": delta,
-            "invoice_number": day.invoice,
-        }
-        daily_entries.append(x1)
-
-    template = env.get_template("view_hours_worked_per_day_summary.j2")
-    daily_entries = sorted(daily_entries, key=lambda i: i["date"], reverse=True)
-    out = template.render(
-        data={
-            "summary": {"total_seconds_worked": total_seconds},
-            "entries": daily_entries,
-        }
-    )
-    return out
-
-
 def view_invoices(timesheet: model.Timesheet):
     template = env.get_template("view_invoices.j2")
     invoices = timesheet.invoices.__root__
